extension YModel on Map {
  T? byModel<T>(String key, T? Function(Map<dynamic, dynamic> value) onModel, {T? defaultValue}) {
    if (this[key] == null) return defaultValue;
    return onModel.call(this[key]) ?? defaultValue;
  }

  List<T>? byList<T>(String key, T Function(Map<dynamic, dynamic> value) onModel, {List<T>? defaultValue}) {
    if (this[key] == null) return defaultValue;
    if (this[key] is! List) return defaultValue;
    return (this[key] as List).map((e) => onModel.call(e)).toList();
  }

  String? byString(String key, {String? defaultValue}) {
    if (this[key] == null) return defaultValue;
    return this[key]?.toString() ?? defaultValue;
  }

  int? byInt(String key, {int? defaultValue}) {
    if (this[key] == null) return defaultValue;
    return double.tryParse(byString(key)!)?.toInt() ?? defaultValue;
  }

  double? byDouble(String key, {double? defaultValue}) {
    if (this[key] == null) return defaultValue;
    return double.tryParse(byString(key)!) ?? defaultValue;
  }

  bool? byBool(String key, {bool? defaultValue}) {
    if (this[key] == null) return defaultValue;
    return byString(key) == "true";
  }

  T? byEnum<T, E>(String key, T? Function(String? value) onModel, {T? defaultValue}) {
    if (this[key] == null) return defaultValue;
    return onModel.call(this[key]?.toString()) ?? defaultValue;
  }
}

// class _DemoModel {
//   _DemoSubModel? model_Null;
//   late _DemoSubModel model_NotNull;
//   List<_DemoSubModel>? list_Null;
//   late List<_DemoSubModel> list_NotNull;
//   String? string_Null;
//   late String string_NotNull;
//   int? int_Null;
//   late int int_NotNull;
//   bool? bool_Null;
//   late bool bool_NotNull;
//   _DemoEnum? enum_Null;
//   late _DemoEnum enum_NotNull;
//
//   _DemoModel.fromMap(Map<dynamic, dynamic> map) {
//     model_Null = map.byModel("modelNull", (value) => _DemoSubModel.fromMap(value));
//     model_NotNull = map.byModel("modelNotNull", (value) => _DemoSubModel.fromMap(value), defaultValue: _DemoSubModel())!;
//     list_Null = map.byList("listNull", (value) => _DemoSubModel.fromMap(value));
//     list_NotNull = map.byList("listNotNull", (value) => _DemoSubModel.fromMap(value), defaultValue: [])!;
//     string_Null = map.byString("stringNull");
//     string_NotNull = map.byString("stringNotNull", defaultValue: "")!;
//     int_Null = map.byInt("intNull");
//     int_NotNull = map.byInt("intNotNull", defaultValue: 0)!;
//     bool_Null = map.byBool("boolNull");
//     bool_NotNull = map.byBool("boolNotNull", defaultValue: false)!;
//     enum_Null = map.byEnum("enumNull", (value) => _DemoEnum.from(value));
//     enum_NotNull = map.byEnum("enumNotNull", (value) => _DemoEnum.from(value), defaultValue: _DemoEnum.UnKnown)!;
//   }
// }
//
// enum _DemoEnum {
//   UnKnown,
//   Enum1(rawValue: "Enum1"),
//   ;
//
//   final String? rawValue;
//
//   const _DemoEnum({this.rawValue});
//
//   static _DemoEnum from(String? rawValue) => values.firstWhere((x) => x.rawValue == rawValue, orElse: () => UnKnown);
// }
//
// class _DemoSubModel {
//   _DemoSubModel();
//
//   _DemoSubModel.fromMap(Map<dynamic, dynamic> map);
// }
